summaryrefslogtreecommitdiff
path: root/src/pkg/runtime/type.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/pkg/runtime/type.go')
-rw-r--r--src/pkg/runtime/type.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/pkg/runtime/type.go b/src/pkg/runtime/type.go
index 71ad4e7a5..30f3ec642 100644
--- a/src/pkg/runtime/type.go
+++ b/src/pkg/runtime/type.go
@@ -117,8 +117,9 @@ type UnsafePointerType commonType
// ArrayType represents a fixed array type.
type ArrayType struct {
commonType
- elem *Type // array element type
- len uintptr
+ elem *Type // array element type
+ slice *Type // slice type
+ len uintptr
}
// SliceType represents a slice type.